==> duckdb_0.6.1.tar.gz: duckdb/src/duckdb/ub_src_parser_transform_statement.cpp <==
#include "src/parser/transform/statement/transform_alter_table.cpp"

#include "src/parser/transform/statement/transform_call.cpp"

#include "src/parser/transform/statement/transform_checkpoint.cpp"

#include "src/parser/transform/statement/transform_create_function.cpp"

#include "src/parser/transform/statement/transform_copy.cpp"

#include "src/parser/transform/statement/transform_create_table_as.cpp"

#include "src/parser/transform/statement/transform_create_index.cpp"

#include "src/parser/transform/statement/transform_create_schema.cpp"

#include "src/parser/transform/statement/transform_create_table.cpp"

#include "src/parser/transform/statement/transform_create_view.cpp"

#include "src/parser/transform/statement/transform_create_type.cpp"

#include "src/parser/transform/statement/transform_delete.cpp"

#include "src/parser/transform/statement/transform_explain.cpp"

#include "src/parser/transform/statement/transform_export.cpp"

#include "src/parser/transform/statement/transform_drop.cpp"

#include "src/parser/transform/statement/transform_import.cpp"

#include "src/parser/transform/statement/transform_insert.cpp"

#include "src/parser/transform/statement/transform_load.cpp"

#include "src/parser/transform/statement/transform_pragma.cpp"

#include "src/parser/transform/statement/transform_rename.cpp"

#include "src/parser/transform/statement/transform_select.cpp"

#include "src/parser/transform/statement/transform_select_node.cpp"

#include "src/parser/transform/statement/transform_set.cpp"

#include "src/parser/transform/statement/transform_prepare.cpp"

#include "src/parser/transform/statement/transform_show.cpp"

#include "src/parser/transform/statement/transform_show_select.cpp"

#include "src/parser/transform/statement/transform_transaction.cpp"

#include "src/parser/transform/statement/transform_update.cpp"

#include "src/parser/transform/statement/transform_create_sequence.cpp"

#include "src/parser/transform/statement/transform_vacuum.cpp"

#include "src/parser/transform/statement/transform_alter_sequence.cpp"

==> duckdb_0.6.2.tar.gz: duckdb/src/duckdb/ub_src_parser_transform_statement.cpp <==
#include "src/parser/transform/statement/transform_alter_table.cpp"

#include "src/parser/transform/statement/transform_attach.cpp"

#include "src/parser/transform/statement/transform_call.cpp"

#include "src/parser/transform/statement/transform_checkpoint.cpp"

#include "src/parser/transform/statement/transform_create_function.cpp"

#include "src/parser/transform/statement/transform_copy.cpp"

#include "src/parser/transform/statement/transform_create_table_as.cpp"

#include "src/parser/transform/statement/transform_create_index.cpp"

#include "src/parser/transform/statement/transform_create_schema.cpp"

#include "src/parser/transform/statement/transform_create_table.cpp"

#include "src/parser/transform/statement/transform_create_view.cpp"

#include "src/parser/transform/statement/transform_create_type.cpp"

#include "src/parser/transform/statement/transform_delete.cpp"

#include "src/parser/transform/statement/transform_explain.cpp"

#include "src/parser/transform/statement/transform_export.cpp"

#include "src/parser/transform/statement/transform_drop.cpp"

#include "src/parser/transform/statement/transform_import.cpp"

#include "src/parser/transform/statement/transform_insert.cpp"

#include "src/parser/transform/statement/transform_load.cpp"

#include "src/parser/transform/statement/transform_pragma.cpp"

#include "src/parser/transform/statement/transform_rename.cpp"

#include "src/parser/transform/statement/transform_select.cpp"

#include "src/parser/transform/statement/transform_select_node.cpp"

#include "src/parser/transform/statement/transform_set.cpp"

#include "src/parser/transform/statement/transform_prepare.cpp"

#include "src/parser/transform/statement/transform_show.cpp"

#include "src/parser/transform/statement/transform_show_select.cpp"

#include "src/parser/transform/statement/transform_transaction.cpp"

#include "src/parser/transform/statement/transform_update.cpp"

#include "src/parser/transform/statement/transform_use.cpp"

#include "src/parser/transform/statement/transform_create_sequence.cpp"

#include "src/parser/transform/statement/transform_vacuum.cpp"

#include "src/parser/transform/statement/transform_alter_sequence.cpp"
